@@ -5,7 +5,7 @@ BEGIN {
     }
 }
 use Encode;
-our $VERSION = do { my @r = (q$Revision: 0.93 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 0.94 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use XSLoader;
 XSLoader::load('Encode::JP',$VERSION);
@@ -28,7 +28,7 @@ Encode::JP - Japanese Encodings
 
 =head1 SYNOPSIS
 
-    use Encode 'encode';
+    use Encode qw/encode decode/; 
     $euc_jp = encode("euc-jp", $utf8);   # loads Encode::JP implicitly
     $utf8   = decode("euc-jp", $euc_jp); # ditto
 
